summaryrefslogtreecommitdiff
path: root/src/theory/theory_engine.h
diff options
context:
space:
mode:
authorDejan Jovanović <dejan.jovanovic@gmail.com>2012-02-24 20:29:12 +0000
committerDejan Jovanović <dejan.jovanovic@gmail.com>2012-02-24 20:29:12 +0000
commitd8da6a3644d1cdbe62d44a8eb80068da4d1d2855 (patch)
tree773ccef817d1e5cbad85b4c0a1fb44666b1e0600 /src/theory/theory_engine.h
parent5a20a19a30929ad58a9e64a9d8d1f877f3a07ae6 (diff)
Theory interface changes:
solve -> ppAsert staticLearning -> ppStaticLearn preprocess -> ppRewrite SolveStatus -> PPAssertStatus (SOLVE_* -> PP_ASSERT_*) via Eclipse refactoring magic.
Diffstat (limited to 'src/theory/theory_engine.h')
-rw-r--r--src/theory/theory_engine.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/theory/theory_engine.h b/src/theory/theory_engine.h
index 2c1c9a436..ceefa88e8 100644
--- a/src/theory/theory_engine.h
+++ b/src/theory/theory_engine.h
@@ -507,7 +507,7 @@ public:
/**
* Solve the given literal with a theory that owns it.
*/
- theory::Theory::SolveStatus solve(TNode literal,
+ theory::Theory::PPAssertStatus solve(TNode literal,
theory::SubstitutionMap& substitutionOut);
/**
@@ -543,10 +543,10 @@ public:
void combineTheories();
/**
* Calls staticLearning() on all theories, accumulating their
* combined contributions in the "learned" builder.
*/
- void staticLearning(TNode in, NodeBuilder<>& learned);
+ void ppStaticLearn(TNode in, NodeBuilder<>& learned);
/**
* Calls presolve() on all theories and returns true
generated by cgit on debian on lair
@@ -543,10 +543,10 @@ public:
void combineTheories();
/**
- * Calls staticLearning() on all theories, accumulating their
+ * Calls ppStaticLearn() on all theories, accumulating their
* combined contributions in the "learned" builder.
*/
contact matthew@masot.net with questions or feedback